# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog][1]
and this project adheres to [Semantic Versioning][2].

## [Unreleased]

[1]: https://keepachangelog.com/en/1.1.0/

[2]: https://semver.org/spec/v2.0.0.html
